==> haskell-hspec-wai-0.9.2-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.2
id: hspec-wai-0.9.2-J80eixPLom6BNARUcdF6Om
key: hspec-wai-0.9.2-J80eixPLom6BNARUcdF6Om
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 814ff7eb347e32bb5bb907fd2202fe8c
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-0.9.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-wai-0.9.2
hs-libraries: HShspec-wai-0.9.2-J80eixPLom6BNARUcdF6Om
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-core-2.7.0-FHQIsoe61ky6Pm3A6Cnxm7
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    http-types-0.12.3-9JOxTMGKnB3BjtQmfYBz9z text-1.2.3.1
    transformers-0.5.6.2 wai-3.2.2-9SAFBQJZAEOFPrdF6aQHMI
    wai-extra-3.0.25-3sAkNUwd7MaJTQh4Jqgteq
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.2-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.2
id: hspec-wai-0.9.2-1IinRMeh7DBFqC5dYlpiMW
key: hspec-wai-0.9.2-1IinRMeh7DBFqC5dYlpiMW
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 5957d739d4b85129dd81344774a90877
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-0.9.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-wai-0.9.2
hs-libraries: HShspec-wai-0.9.2-1IinRMeh7DBFqC5dYlpiMW
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-core-2.7.0-9NnDleZEH4rJ9g7wAFIQaO
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    http-types-0.12.3-31d6LQ68qwwd6igf1kSi7 text-1.2.3.1
    transformers-0.5.6.2 wai-3.2.2-6tLP3XRzZhv64EbPHCO0pJ
    wai-extra-3.0.25-IT9JTKJGvo8ENFY4H5HwHB
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
